#ifndef CHROMEOS_CAMERA_LIB_KIOSK_VISION_PUBLIC_KIOSK_AUDIENCE_MEASUREMENT_BINDINGS_H_
#define CHROMEOS_CAMERA_LIB_KIOSK_VISION_PUBLIC_KIOSK_AUDIENCE_MEASUREMENT_BINDINGS_H_

#include <cstdint>

#include "kiosk_audience_measurement_types.h"  // NOLINT(build/include)

extern "C" {

// Status codes for kiosk vision bindings.
typedef enum {
  CROS_KIOSK_VISION_OK = 0,
  CROS_KIOSK_VISION_ERROR = 1,
} cros_kiosk_vision_status_t;

// Called when the frame with `timestamp` is processed and can be
// released. `audience_data` and `audience_size` represent a result array of
// objects that are currently tracked.
typedef void (*cros_kiosk_vision_OnFrameProcessedCallbackFn)(
  cros::kiosk_vision::Timestamp timestamp,
  cros::kiosk_vision::Person* audience_data, uint32_t audience_size);

// Creates an audience measurement pipeline.
// Sets an `out_handle` (pointer) to the object.
cros_kiosk_vision_status_t cros_kiosk_vision_CreateKioskAudienceMeasurement(
  cros_kiosk_vision_OnFrameProcessedCallbackFn callback, void** out_handle);

typedef decltype(&cros_kiosk_vision_CreateKioskAudienceMeasurement)
    cros_kiosk_vision_CreateKioskAudienceMeasurementFn;

// Deletes an audience measurement pipeline under `handle`.
cros_kiosk_vision_status_t cros_kiosk_vision_DeleteKioskAudienceMeasurement(
    void* handle);

typedef decltype(&cros_kiosk_vision_DeleteKioskAudienceMeasurement)
    cros_kiosk_vision_DeleteKioskAudienceMeasurementFn;

// Gets the size and color format of the detection model.
cros_kiosk_vision_status_t cros_kiosk_vision_GetDetectorInputProperties(
  void* handle, cros::kiosk_vision::ImageSize* size,
  cros::kiosk_vision::ImageFormat* format);

typedef decltype(&cros_kiosk_vision_GetDetectorInputProperties)
    cros_kiosk_vision_GetDetectorInputPropertiesFn;

// Enqueues an image to the `handle` pipeline to run processing.
// `cros_kiosk_vision_OnFrameProcessedCallbackFn` is called when the processing
// is complete. The client code should keep `frame` pixel data buffer until it
// receives a callback is with the same timestamp.
cros_kiosk_vision_status_t cros_kiosk_vision_ProcessFrame(
    void* handle, cros::kiosk_vision::Timestamp timestamp,
    const cros::kiosk_vision::InputFrame* frame);

typedef decltype(&cros_kiosk_vision_ProcessFrame)
    cros_kiosk_vision_ProcessFrameFn;

// Waits until the `handle` pipeline processed all enqueued frames.
cros_kiosk_vision_status_t cros_kiosk_vision_WaitUntilIdle(void* handle);

typedef decltype(&cros_kiosk_vision_WaitUntilIdle)
    cros_kiosk_vision_WaitUntilIdleFn;

}

#endif  // CHROMEOS_CAMERA_LIB_KIOSK_VISION_PUBLIC_KIOSK_AUDIENCE_MEASUREMENT_BINDINGS_H_
