#ifndef CHROMEOS_CAMERA_LIB_KIOSK_VISION_PUBLIC_KIOSK_AUDIENCE_MEASUREMENT_TYPES_H_
#define CHROMEOS_CAMERA_LIB_KIOSK_VISION_PUBLIC_KIOSK_AUDIENCE_MEASUREMENT_TYPES_H_

#include <cstdint>

namespace cros::kiosk_vision {

// A timestamp of data (e.g. input frame or results) in the processing pipeline.
// Measured in microseconds.
using Timestamp = int64_t;

// 2d size of the input image.
struct ImageSize {
  int32_t width;
  int32_t height;
};

// Color format of the input image. Defines the depth of the image buffer.
enum class ImageFormat : uint8_t {
  // Grayscale, one channel, 8 bits per pixel.
  kGray8 = 0,
};

// Input frame of the processing pipeline.
struct InputFrame {
  ImageSize size;
  ImageFormat format;
  const uint8_t* pixel_data;
  int32_t stride;
};

struct Rect {
  int32_t x_min;
  int32_t x_max;
  int32_t y_min;
  int32_t y_max;
};

struct FaceAngles {
  float roll;
  float pan;
  float tilt;
};

struct FaceDetection {
  Rect bounding_box;
  FaceAngles angles;
  double confidence;
};

struct BodyDetection {
  Rect bounding_box;
  double confidence;
};

using TrackID = int32_t;

struct Person {
  TrackID track_id;

  bool is_face_detected;
  FaceDetection face;
  bool is_body_detected;
  BodyDetection body;
};

}  // namespace cros::kiosk_vision

#endif  // CHROMEOS_CAMERA_LIB_KIOSK_VISION_PUBLIC_KIOSK_AUDIENCE_MEASUREMENT_TYPES_H_
